package com.ruoyi.ems.mapper;

import com.ruoyi.ems.domain.EmsDeviceComponent;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 能源设备部件Mapper接口
 *
 * @author ruoyi
 * @date 2024-09-23
 */
public interface EmsDeviceComponentMapper {
    /**
     * 查询能源设备部件
     *
     * @param id 能源设备部件主键
     * @return 能源设备部件
     */
    EmsDeviceComponent selectById(Long id);

    /**
     * 查询能源设备部件
     *
     * @param compoCode 能源设备部件代码
     * @return 能源设备部件
     */
    EmsDeviceComponent selectByCode(@Param("compoCode") String compoCode);

    /**
     * 查询能源设备部件列表
     *
     * @param deviceComponent 能源设备部件
     * @return 能源设备部件集合
     */
    List<EmsDeviceComponent> selectList(EmsDeviceComponent deviceComponent);

    /**
     * 查询能源设备部件列表
     *
     * @param deviceCode 设备代码
     * @return 能源设备部件集合
     */
    List<EmsDeviceComponent> selectByDeviceCode(@Param("deviceCode") String deviceCode);

    /**
     * 新增能源设备部件
     *
     * @param deviceComponent 能源设备部件
     * @return 结果
     */
    int insertComponent(EmsDeviceComponent deviceComponent);

    /**
     * 修改能源设备部件
     *
     * @param deviceComponent 能源设备部件
     * @return 结果
     */
    int updateComponent(EmsDeviceComponent deviceComponent);

    /**
     * 删除能源设备部件
     *
     * @param id 能源设备部件主键
     * @return 结果
     */
    int deleteComponentById(Long id);

    /**
     * 批量删除能源设备部件
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteComponentByIds(Long[] ids);
}
